@@ -7,7 +7,7 @@ class ResetPasswordManager(Manager):
         try:
             token = self.get(
                 token=token,
-                status=self.model.STATUS.pending,
+                status=self.model.STATUS.PENDING.value,
                 expire_date__gte=timezone.now(),
             )
         except self.model.DoesNotExist:
