@@ -1,14 +1,12 @@
-import os
 import uuid
 from datetime import timedelta
-from pathlib import Path
+from enum import Enum
 from pydoc import locate
 
+import django
 from django.db import models
 from django.template.loader import render_to_string
 from django.utils import timezone
-from model_utils import Choices
-from model_utils.models import TimeStampedModel, StatusModel
 
 from reset_password.exceptions import (
     EmailProviderClassNotSet,
@@ -18,16 +16,26 @@ from reset_password.managers import ResetPasswordManager
 from django.conf import settings
 
 
-class ResetPasswordToken(StatusModel, TimeStampedModel):
-    STATUS = Choices("accepted", "pending", "invalid")
+class StatusType(Enum):
+    ACCEPTED = "accepted"
+    PENDING = "pending"
+    INVALID = "invalid"
+
+
+STATUS_TYPES = [(e.value, e.value) for e in StatusType]
+
+
+class ResetPasswordToken(models.Model):
+    STATUS = StatusType
     token = models.UUIDField(primary_key=False, default=uuid.uuid4)
     expire_date = models.DateTimeField(null=True)
     user = models.OneToOneField(
         settings.AUTH_USER_MODEL,
-        related_name="email_confirmation",
+        related_name="reset_password",
         on_delete=models.CASCADE,
     )
-    status = models.CharField(choices=STATUS, default=STATUS.pending, max_length=100)
+    status = models.CharField(choices=STATUS_TYPES, default=StatusType.PENDING.value, max_length=100)
+    created = models.DateTimeField(default=django.utils.timezone.now)
     objects = ResetPasswordManager()
 
     def save(self, *args, **kwargs):
@@ -53,9 +61,9 @@ class ResetPasswordToken(StatusModel, TimeStampedModel):
         return mail.send_email(email, self._get_email_title(), content)
 
     def update_password(self, password: str):
-        self.set_password(password)
+        self.user.set_password(password)
         self.user.save()
-        self.status = self.STATUS.accepted
+        self.status = StatusType.ACCEPTED.value
         self.save()
 
     def _get_user_email(self):
